
# Slot: alias


the name used for a slot in the context of its owning class.  If present, this is used instead of the actual slot name.

URI: [linkml:alias](https://w3id.org/linkml/alias)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [String](String.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
